==> mozc_1.5.1053.102.orig.tar.gz: mozc-1.5.1053.102/session/request_test_util.h <==
// Copyright 2010-2012, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// Test utility for Request.

#ifndef MOZC_SESSION_REQUEST_TEST_UTIL_H_
#define MOZC_SESSION_REQUEST_TEST_UTIL_H_

#include "base/base.h"
#include "session/commands.pb.h"

namespace mozc {
namespace commands {
class ScopedRequestForUnittest {
 public:
  ScopedRequestForUnittest(const Request &request);
  virtual ~ScopedRequestForUnittest();

 private:
  const Request prev_request_;
};

class ScopedMobileRequestForUnittest {
 public:
  ScopedMobileRequestForUnittest();
  virtual ~ScopedMobileRequestForUnittest();

 private:
  scoped_ptr<ScopedRequestForUnittest> scoped_request_;
};
}  // namespace commands
}  // namespace mozc
#endif  // MOZC_SESSION_REQUEST_TEST_UTIL_H_

==> mozc_1.6.1187.102.orig.tar.gz: mozc-1.6.1187.102/session/request_test_util.h <==
// Copyright 2010-2012, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// Test utility for Request.

#ifndef MOZC_SESSION_REQUEST_TEST_UTIL_H_
#define MOZC_SESSION_REQUEST_TEST_UTIL_H_

#include "base/base.h"
#include "session/commands.pb.h"

namespace mozc {
namespace commands {
class ScopedRequestForUnittest {
 public:
  explicit ScopedRequestForUnittest(const Request &request);
  virtual ~ScopedRequestForUnittest();

 private:
  const Request prev_request_;

  DISALLOW_COPY_AND_ASSIGN(ScopedRequestForUnittest);
};

class ScopedMobileRequestForUnittest {
 public:
  ScopedMobileRequestForUnittest();
  virtual ~ScopedMobileRequestForUnittest();

 private:
  scoped_ptr<ScopedRequestForUnittest> scoped_request_;

  DISALLOW_COPY_AND_ASSIGN(ScopedMobileRequestForUnittest);
};

class RequestForUnitTest {
 public:
  static void FillMobileRequest(Request *request);

 private:
  DISALLOW_IMPLICIT_CONSTRUCTORS(RequestForUnitTest);
};
}  // namespace commands
}  // namespace mozc
#endif  // MOZC_SESSION_REQUEST_TEST_UTIL_H_
